@@ -51,17 +51,18 @@ class WSA5000_220Properties(object):
     NOISEFLOOR_CALIBRATION = -10
     CAPTURE_FREQ_RANGES = [(50*M, 20000*M, IQ)]
     SWEEP_FREQ_RANGE = (100*M, 20000*M)
-
+    RFE_ATTENUATION = 20
     RFE_MODES = ('ZIF', 'SH', 'SHN', 'HDR', 'IQIN', 'DD')
 
     FULL_BW = {'ZIF': 125*M, 'HDR': 162760, 'SH': 62500000 , 'SHN': 62500000, 'IQIN': 62500000, 'DD': 62500000}
-    USABLE_BW = {'ZIF': 100*M, 'HDR': 100000, 'SH': 40000000,'SHN': 10000000, 'IQIN': 50000000, 'DD': 0}
-    MIN_TUNABLE = {'ZIF': 50*M, 'HDR': 50*M, 'SH': 50*M, 'SHN': 50*M,'IQIN': 0.1*M, 'DD': 0}
-    MAX_TUNABLE = {'ZIF': 20000*M, 'HDR': 20000*M, 'SH': 20000*M,'SHN': 20000*M, 'IQIN': 0.1*M, 'DD': 0}
+    USABLE_BW = {'ZIF': 100*M, 'HDR': 100000, 'SH': 40000000,'SHN': 40000000, 'IQIN': 50000000, 'DD': 62500000}
+    MIN_TUNABLE = {'ZIF': 50*M, 'HDR': 50*M, 'SH': 50*M, 'SHN': 50*M,'IQIN': 0.1*M, 'DD': 31.2*M}
+    MAX_TUNABLE = {'ZIF': 20000*M, 'HDR': 20000*M, 'SH': 20000*M,'SHN': 20000*M, 'IQIN': 0.1*M, 'DD': 31.2*M}
     MIN_DECIMATION = {'ZIF': 4, 'HDR': None, 'SH': 4, 'SHN': 4,'IQIN': None, 'DD': None}
     MAX_DECIMATION = {'ZIF': 1024, 'HDR': None, 'SH': 4, 'SHN': 4,'IQIN': None, 'DD': None}
     DECIMATED_USABLE = 0.80
-    PASS_BAND_CENTER = {'ZIF': 0.5, 'HDR': 0.6, 'SH': 0.56, 'SHN': 0.56,'IQIN': 0.5, 'DD': 0.5}
+    PASS_BAND_CENTER = {'ZIF': 0.5, 'HDR': 0.6, 'SH': 0.56, 'SHN': 0.45,'IQIN': 0.5, 'DD': 0.5}
+    PASS_BAND_OFFSET = {'SHN': 7*M}
     DC_OFFSET_BW = 240000 # XXX: an educated guess
     TUNING_RESOLUTION = 100000
     FSHIFT_AVAILABLE = {'ZIF': True, 'HDR': False, 'SH': True, 'SHN': True,'IQIN': False, 'DD': False}
@@ -71,11 +72,9 @@ class WSA5000_220Properties(object):
         'dwell_s', 'dwell_us',
         'trigtype', 'level_fstart', 'level_fstop', 'level_amplitude']
 
-
 class WSA5000_220_v2Properties(WSA5000_220Properties):
     model = 'WSA5000-220 v2'
     # v2 -> hardware revision without SHN mode
-
     RFE_MODES = ('ZIF', 'SH', 'HDR', 'IQIN', 'DD')
 
 
@@ -86,6 +85,10 @@ class WSA5000_208Properties(WSA5000_220Properties):
     MAX_TUNABLE = dict((mode, min(8000*M, f))
         for mode, f in WSA5000_220Properties.MAX_TUNABLE.iteritems())
 
+class WSA5000_108Properties(WSA5000_208Properties):
+    model = 'WSA5000-108'
+    # 108 -> limited to SHN, HDR, and DD mode
+    RFE_MODES = ('SHN', 'HDR', 'DD')
 
 class WSA5000_208_v2Properties(WSA5000_220_v2Properties, WSA5000_208Properties):
     model = 'WSA5000-208 v2'
@@ -145,6 +148,8 @@ class WSA(object):
             self.properties = WSA5000_208_v2Properties
         elif device_id.startswith('ThinkRF,WSA5000-208'):
             self.properties = WSA5000_208Properties
+        elif device_id.startswith('ThinkRF,WSA5000-108'):
+            self.properties = WSA5000_108Properties
         else:
             self.properties = WSA5000_220Properties
 
