@@ -42,8 +42,8 @@ RBW_VALUES = [976.562, 488.281, 244.141, 122.070, 61.035, 30.518, 15.259, 7.6293
 
 HDR_RBW_VALUES = [1271.56, 635.78, 317.890, 158.94, 79.475, 39.736, 19.868, 9.934]
 
-PLOT_YMIN = -160
-PLOT_YMAX = 20
+PLOT_YMIN = -140
+PLOT_YMAX = 0
 
 ZIF_BITS = 2**13
 CONST_POINTS = 512
@@ -198,8 +198,13 @@ class MainPanel(QtGui.QWidget):
             self.ref_level = data['context_pkt']['reflevel']
 
         self.pow_data = compute_fft(self.dut, data['data_pkt'], data['context_pkt'], ref = self.ref_level)
+        
+        if self.plot_state.dev_set['attenuator']:
+            self.pow_data += self.dut_prop.RFE_ATTENUATION
+            
         self.raw_data = data['data_pkt']
 
+
         self.update_plot()
 
     def receive_sweep(self, fstart, fstop, data):
@@ -427,6 +432,17 @@ class MainPanel(QtGui.QWidget):
             input_mode = self._dev_group._mode.currentText()
             if not input_mode:
                 return
+
+            if self.plot_state.dev_set['rfe_mode'] == 'IQIN' or self.plot_state.dev_set['rfe_mode'] == 'DD':
+                self._freq_edit.setText(str(self.dut_prop.MIN_TUNABLE[input_mode.split(" ")[-1]]/M))
+                self.plot_state.update_freq_set(fcenter = self.dut_prop.MIN_TUNABLE[input_mode.split(" ")[-1]])
+                self.update_freq_edit()
+
+            if input_mode == 'IQIN' or input_mode == 'DD':
+                self._freq_edit.setText(str(self.dut_prop.MIN_TUNABLE[input_mode.split(" ")[-1]]/M))
+                self.plot_state.update_freq_set(fcenter = self.dut_prop.MIN_TUNABLE[input_mode.split(" ")[-1]])
+                self.update_freq_edit()
+
             if input_mode.startswith('Sweep '):
 
                 self._plot.const_window.hide()
@@ -438,25 +454,23 @@ class MainPanel(QtGui.QWidget):
                 self._dev_group._dec_box.setEnabled(False)
                 self._dev_group._freq_shift_edit.setEnabled(False)
                 self._sweep_mode = input_mode.split(' ',1)[1]
-
                 return
+            else:
+                self._plot.const_window.show()
+                self._plot.iq_window.show()
+                self.plot_state.enable_block_mode(self)
 
-            self._plot.const_window.show()
-            self._plot.iq_window.show()
-            self.plot_state.enable_block_mode(self)
+            self.plot_state.dev_set['rfe_mode'] = str(input_mode.split(" ")[-1])
+            cu._update_rbw_values(self)
 
             self.plot_state.dev_set['rfe_mode'] = str(input_mode)
-            cu._update_rbw_values(self)
-            self.plot_state.bandwidth = self.dut_prop.FULL_BW[input_mode]
-            if self.plot_state.dev_set['rfe_mode'] == 'IQIN':
-                self._freq_edit.setText(str(self.dut_prop.MIN_TUNABLE[self.plot_state.dev_set['rfe_mode']]/M))
+            self._bw_edit.setText(str(float(self.dut.properties.FULL_BW[input_mode])/ M))
+            self.plot_state.update_freq_set(bw = self.dut.properties.FULL_BW[input_mode])
+            self.update_freq_edit()
 
-            self.plot_state.update_freq_set(
-                fcenter=float(self._freq_edit.text()) * M)
-            self._bw_edit.setText(str(float(self.dut.properties.FULL_BW[self.plot_state.dev_set['rfe_mode']])/ M) + '\n')
             self.cap_dut.configure_device(self.plot_state.dev_set)
 
-            self._rbw_box.setCurrentIndex(4 if input_mode == 'SH' else 3)
+            self._rbw_box.setCurrentIndex(6 if input_mode in ('SHN', 'SH') else 3)
             cu._center_plot_view(self)
             if input_mode == 'HDR':
                 self._dev_group._dec_box.setEnabled(False)
@@ -665,7 +679,7 @@ class MainPanel(QtGui.QWidget):
             else:
                 self.plot_state.update_freq_set(rbw = self._hdr_points_values[rbw.currentIndex()])
 
-        rbw.setCurrentIndex(0)
+        rbw.setCurrentIndex(3)
         rbw.currentIndexChanged.connect(new_rbw)
         self.control_widgets.append(self._rbw_box)
         return rbw
@@ -678,7 +692,7 @@ class MainPanel(QtGui.QWidget):
         min_tunable = prop.MIN_TUNABLE[rfe_mode]
         max_tunable = prop.MAX_TUNABLE[rfe_mode]
         if delta == None:
-            delta = 0    
+            delta = 0
         try:
             if self.plot_state.freq_sel == 'CENT':
                 f = (float(self._freq_edit.text()) + delta) * M
@@ -701,7 +715,7 @@ class MainPanel(QtGui.QWidget):
             
             elif self.plot_state.freq_sel == 'BW':
                 f = (float(self._bw_edit.text()) + delta) * M
-                if f < 0:
+                if self.plot_state.center_freq - (f / 2) < min_tunable or self.plot_state.center_freq + (f / 2) > max_tunable:
                     return
                 self.plot_state.update_freq_set(bw = f)
             for trace in self._plot.traces:
@@ -718,10 +732,10 @@ class MainPanel(QtGui.QWidget):
                 self._plot.freqtrig_lines.setRegion([self.plot_state.fstart,self.plot_state. fstop]) 
 
     def update_freq_edit(self):
-        self._fstop_edit.setText("%0.1f" % (self.plot_state.fstop/ 1e6))
-        self._fstart_edit.setText("%0.1f" % (self.plot_state.fstart/ 1e6))
-        self._freq_edit.setText("%0.1f" % (self.plot_state.center_freq / 1e6))
-        self._bw_edit.setText("%0.1f" % (self.plot_state.bandwidth / 1e6))
+        self._fstop_edit.setText("%0.1f" % (self.plot_state.fstop/ M))
+        self._fstart_edit.setText("%0.1f" % (self.plot_state.fstart/ M))
+        self._freq_edit.setText("%0.1f" % (self.plot_state.center_freq / M))
+        self._bw_edit.setText("%0.1f" % (self.plot_state.bandwidth / M))
         self._center_bt.click()
 
     def _plot_controls(self):
@@ -830,19 +844,24 @@ class MainPanel(QtGui.QWidget):
        
         self.plot_state.update_freq_range(self.plot_state.fstart,
                                               self.plot_state.fstop, 
-                                              len(self.pow_data))
+                                              len(self.pow_data),
+                                              self.plot_state.dev_set['rfe_mode'],
+                                              self.raw_data.spec_inv)
         self.update_trace()
         self.update_iq()
         self.update_marker()
         self.update_diff()
 
     def update_trace(self):
+
+        #FIXME make alternate_colors user defined
         for trace in self._plot.traces:
             trace.update_curve(
                 self.plot_state.freq_range,
                 self.pow_data,
                 self.usable_bins,
-                self.sweep_segments)
+                self.sweep_segments,
+                self.plot_state.alt_colors)
 
 
     def update_iq(self):
